@@ -177,13 +177,11 @@ class GSPeerConnectionBroadcasterPiSocket:
         @self.sio.event
         async def disconnectPeer(id):
             if id in self.peerConnections:
-                self._logger.info("closeConnection")
+                self._logger.info("Disconnected Peer")
                 await self.peerConnections[id].close()
                 self.peerConnections.pop(id, None)
 
-        # @self.sio.event
-        # async def candidate(id, candidate):
-        #     await self.peerConnections[id].addIceCandidate()
+
 
         @self.sio.event
         async def disconnect():
